<%include file="/pageheader.html"/> <%! from kaithem.src import messagelogging, settings_overrides import time from kaithem.src.util import url from kaithem.src.config import config def formattime(x): return time.strftime(settings_overrides.get_val('core/strftime_string'),time.localtime(x)) %>

## Old log dumps

These are old log dump files you can download. The oldest are automatically deleted once there are too many.

Time | Compression Type | File Size | Download
%for i in reversed(sorted(files,key = lambda x: x[0])):
${formattime(i[0])} | ${i[2]|h} | ${i[3]/1000|h}KB | Dowload
%endfor>

<%include file="/pagefooter.html"/>